@@ -802,6 +802,7 @@ class CommunicationStateMixin:
     MAX_COMM_STATE_VALUE = 0x7ffff
 
     def get_communication_state(self) -> Dict[str, typing.Optional[int]]:
+        """Returns information used by the slot allocation algorithm as a dict."""
         result: Dict[str, typing.Optional[int]] = {
             'received_stations': None,
             'slot_number': None,
@@ -1616,10 +1617,10 @@ class MessageType26(Payload):
             if structured:
                 return MessageType26AddressedStructured.create(**kwargs)
             else:
-                return MessageType26BroadcastStructured.create(**kwargs)
+                return MessageType26AddressedUnstructured.create(**kwargs)
         else:
             if structured:
-                return MessageType26AddressedUnstructured.create(**kwargs)
+                return MessageType26AddressedStructured.create(**kwargs)
             else:
                 return MessageType26BroadcastUnstructured.create(**kwargs)
 
