@@ -172,7 +172,7 @@ class BinaryIOStream(Stream[BinaryIO]):
         super().__init__(file)
 
     def read(self) -> Generator[bytes, None, None]:
-        yield from self._fobj.readlines()
+        yield from self._fobj
 
 
 class FileReaderStream(BinaryIOStream):
@@ -223,15 +223,21 @@ class SocketStream(Stream[socket]):
             if not body:
                 return None
 
-            lines = body.split(b'\r\n')
+            lines = body.splitlines(keepends=True)
 
+            # last incomplete line
             line = partial + lines[0]
             if line:
                 yield line
+            partial = b''
 
-            yield from (line for line in lines[1:-1] if line)
-
-            partial = lines[-1]
+            if lines[-1].endswith(b'\n'):
+                # all lines are complete
+                yield from lines[1:]
+            else:
+                # the last line was only partially received
+                yield from lines[1:-1]
+                partial = lines[-1]
 
 
 class UDPReceiver(SocketStream):
